#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Mortal Kombat 3
# send your bug reports to contact@dotslashplay.it
###

script_version=20240428.1

PLAYIT_COMPATIBILITY_LEVEL='2.28'

GAME_ID='mortal-kombat-3'
GAME_NAME='Mortal Kombat Ⅲ'

ARCHIVE_BASE_0_NAME='setup_mortal_kombat3_2.0.0.2.exe'
ARCHIVE_BASE_0_MD5='e9703877b5bd2dfde5b2d65b8586aa6d'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='87000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.2'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/mortal_kombat_123'

CONTENT_PATH_DEFAULT='app/mk3'
CONTENT_GAME_MAIN_FILES='
drivers
image
*.asg
*.bat
*.dat
*.exe
*.ftr
*.ini
*.mk3'

USER_PERSISTENT_FILES='
*.dat
*.ini'

GAME_IMAGE='image/mk3.cue'

APP_MAIN_EXE='mk3.exe'
APP_MAIN_ICON='../goggame-1207667063.ico'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	## Ensure case consistency between the disk image table of contents and the actual filenames.
	sed_pattern='MK3\.GOG'
	sed_replacement='mk3.gog'
	sed_expression="s/${sed_pattern}/${sed_replacement}/"
	sed_pattern='Track'
	sed_replacement='track'
	sed_expression="${sed_expression};s/${sed_pattern}/${sed_replacement}/g"
	sed --in-place --expression="$sed_expression" "$GAME_IMAGE"
)

# Include game data

content_inclusion_icons
content_inclusion_default

# Write launchers

launchers_generation

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
