#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Out of Line
# send your bug reports to contact@dotslashplay.it
###

script_version=20230328.3

GAME_ID='out-of-line'
GAME_NAME='Out of Line'

ARCHIVE_BASE_0='setup_out_of_line_1.0.1.2_(50411).exe'
ARCHIVE_BASE_0_MD5='5cf39c90da563dc21776536b1904b0df'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='1500000'
ARCHIVE_BASE_0_VERSION='1.0.1.2-gog50411'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/out_of_line'

UNITY3D_NAME='out of line'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_BIN_FILES="
monobleedingedge
${UNITY3D_NAME}_data/plugins
${UNITY3D_NAME}.exe
unitycrashhandler64.exe
unityplayer.dll
winpixeventruntime.dll"
CONTENT_GAME_DATA_FILES="
${UNITY3D_NAME}_data"

APP_WINE_LINK_DIRS='
userdata:users/${USER}/AppData/LocalLow/Nerd Monkeys/Out of Line'
USER_PERSISTENT_FILES='
userdata/achievements.save
userdata/gamesave.save
userdata/options.save'

APP_MAIN_EXE="${UNITY3D_NAME}.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
video/quicktime, variant=(string)iso'

# Load common functions

target_version='2.23'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
