#!/bin/sh -e
set -o errexit

###
# Copyright (c) 2020, Hoël Bézier
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Sundered
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20200512.1

# Set game-specific variables

GAME_ID='sundered'
GAME_NAME='Sundered'

ARCHIVE_GOG='sundered_20190404_29317.sh'
ARCHIVE_GOG_URL='https://www.gog.com/game/sundered'
ARCHIVE_GOG_MD5='efd81d3e4b14d26cdef2362b888e0a56'
ARCHIVE_GOG_SIZE='2500000'
ARCHIVE_GOG_VERSION='20190404-gog23987'
ARCHIVE_GOG_TYPE='mojosetup'

ARCHIVE_DOC0_DATA_PATH='data/noarch/docs'
ARCHIVE_DOC0_DATA_FILES='*'

ARCHIVE_DOC1_DATA_PATH='data/noarch/support'
ARCHIVE_DOC1_DATA_FILES='*.txt'

ARCHIVE_GAME_BIN32_PATH='data/noarch/game'
ARCHIVE_GAME_BIN32_FILES='Sundered.x86 Sundered_Data/Mono/x86 Sundered_Data/Plugins/x86'

ARCHIVE_GAME_BIN64_PATH='data/noarch/game'
ARCHIVE_GAME_BIN64_FILES='Sundered.x86_64 Sundered_Data/Mono/x86_64 Sundered_Data/Plugins/x86_64'

ARCHIVE_GAME_DATA_PATH='data/noarch/game'
ARCHIVE_GAME_DATA_FILES='Sundered_Data'

DATA_DIRS='./logs'

APP_MAIN_TYPE='native'
APP_MAIN_EXE_BIN32='Sundered.x86'
APP_MAIN_EXE_BIN64='Sundered.x86_64'
# shellcheck disable=SC2016
APP_MAIN_OPTIONS='-logFile ./logs/$(date +%F-%R).log'
APP_MAIN_ICON='Sundered_Data/Resources/UnityPlayer.png'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID glibc libstdc++ gtk2"

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Load common functions

target_version='2.11'

if [ -z "$PLAYIT_LIB2" ]; then
  : "${XDG_DATA_HOME:="$HOME/.local/share"}"
  for path in\
    "$PWD"\
    "$XDG_DATA_HOME/play.it"\
    '/usr/local/share/games/play.it'\
    '/usr/local/share/play.it'\
    '/usr/share/games/play.it'\
    '/usr/share/play.it'
  do
    if [ -e "$path/libplayit2.sh" ]; then
      PLAYIT_LIB2="$path/libplayit2.sh"
      break
    fi
  done
fi
if [ -z "$PLAYIT_LIB2" ]; then
  printf '\n\033[1;31mError:\033[0m\n'
  printf 'libplayit2.sh not found.\n'
  exit 1
fi
#shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout
rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Extract icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
  launchers_write 'APP_MAIN'
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
