#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Book of Unwritten Tales 2
# send your bug reports to contact@dotslashplay.it
###

script_version=20230623.2

GAME_ID='the-book-of-unwritten-tales-2'
GAME_NAME='The Book of Unwritten Tales 2'

ARCHIVE_BASE_0='gog_the_book_of_unwritten_tales_2_2.0.0.2.sh'
ARCHIVE_BASE_0_MD5='f2b0ca23d7bfc1f7e22fa6f990fc527c'
ARCHIVE_BASE_0_SIZE='13000000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.2'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/the_book_of_unwritten_tales_2_almanac_edition'

# Improved Unity3D plugins integration can not be used,
# because the plugins are not provided in the standard path.
UNITY3D_NAME='BouT2'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_BIN32_FILES="
Linux/${UNITY3D_NAME}.x86
Linux/${UNITY3D_NAME}_Data/Mono/x86
Linux/${UNITY3D_NAME}_Data/Plugins/x86"
CONTENT_GAME_BIN64_FILES="
Linux/${UNITY3D_NAME}.x86_64
Linux/${UNITY3D_NAME}_Data/Mono/x86_64
Linux/${UNITY3D_NAME}_Data/Plugins/x86_64"
CONTENT_GAME_SCENES_FILES="
data/episode_0?/Scenes"
CONTENT_GAME_DATA_FILES="
data
qt.conf
Linux/${UNITY3D_NAME}_Data"

APP_MAIN_EXE_BIN32="Linux/${UNITY3D_NAME}.x86"
APP_MAIN_EXE_BIN64="Linux/${UNITY3D_NAME}.x86_64"
APP_MAIN_ICON="Linux/${UNITY3D_NAME}_Data/Resources/UnityPlayer.png"

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_SCENES PKG_DATA'

PKG_SCENES_ID="${GAME_ID}-scenes"
PKG_SCENES_DESCRIPTION='scenes'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN64_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID $PKG_SCENES"
PKG_BIN32_DEPS="$PKG_BIN_DEPS_DEB"
PKG_BIN64_DEPS="$PKG_BIN_DEPS_DEB"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libatk-1.0.so.0
libcairo.so.2
libc.so.6
libdl.so.2
libfontconfig.so.1
libfreetype.so.6
libgcc_s.so.1
libgdk_pixbuf-2.0.so.0
libgdk-x11-2.0.so.0
libgio-2.0.so.0
libglib-2.0.so.0
libgmodule-2.0.so.0
libgobject-2.0.so.0
libgthread-2.0.so.0
libgtk-x11-2.0.so.0
libm.so.6
libpango-1.0.so.0
libpangocairo-1.0.so.0
libpangoft2-1.0.so.0
libpthread.so.0
librt.so.1
libstdc++.so.6'
PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"

# Load common functions

target_version='2.23'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write
done

# Build packages

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
